@@ -1,11 +1,10 @@
 const { EventEmitter } = require('events');
 const sinon = require('sinon');
 const util = require('util');
-const _ = require('lodash');
 
 const stub = {};
 
-_.extend(stub, {
+Object.assign(stub, {
   write: sinon.stub().returns(stub),
   moveCursor: sinon.stub().returns(stub),
   setPrompt: sinon.stub().returns(stub),
@@ -32,6 +31,6 @@ const ReadlineStub = function () {
 };
 
 util.inherits(ReadlineStub, EventEmitter);
-_.assign(ReadlineStub.prototype, stub);
+Object.assign(ReadlineStub.prototype, stub);
 
 module.exports = ReadlineStub;
